<?php

namespace Drupal\Tests\drupal_test_assertions\Assertions;

use Drupal\workflows\Entity\Workflow;

/**
 * Helper trait to perform assertions related to Content Moderation module.
 */
trait ContentModerationTrait {

  /**
   * Asserts an entity type of a given bundle should be moderated.
   */
  public function assertModerationEnabledForEntityType(string $entity_type, string $bundle) {
    $service = \Drupal::service('content_moderation.moderation_information');
    $this->assertTrue($service->shouldModerateEntitiesOfBundle($entity_type, $bundle), "$entity_type ($bundle) should be moderated.");
  }

  /**
   * Asserts the configured workflow for a entity type.
   */
  public function assertWorkflowForEntityType(string $entity_type, string $bundle) {
    $service = \Drupal::service('content_moderation.moderation_information');
    $workflow = $service->getWorkflowForEntityTypeAndBundle($entity_type, $bundle);

    $error = "$entity_type ($bundle) should use the $workflow_name $workflow";
    $this->assertTrue(!empty($workflow) && $workflow_name === $workflow->id(), $error);
  }

  /**
   * Asserts a transtion exists for a given workflow.
   */
  public function assertWorkflowTransition(string $workflow_name, string $from, string $to) {
    $workflow = Workflow::load($workflow_name);
    $error = "Workflow '$workflow' has a transition from '$from' to '$to'";
    $this->assertTrue($workflow->getTypePlugin()->hasTransitionFromStateToState($from, $to), $error);
  }

}
